init_log

Function init_log 

pub fn init_log(
    level: LevelFilter,
    log_file: String,
    log_file_max: u32,
    use_console: bool,
    use_async: bool,
) -> Result<(), Box<dyn Error + Send + Sync>>
It creates a new logger, initializes it, and then sets it as the global logger

Arguments:

  • level: log level
  • log_file: The log file path. ignore if the value is empty
  • log_file_max: The maximum size of the log file, The units that can be used are k/m/g.
  • use_console: Whether to output to the console
  • use_async: Whether to use asynchronous logging, if true, the log will be written to the file in a separate thread, and the log will not be blocked.

Returns:

A Result<(), anyhow::error>

Examples

asnyclog::init_log(log::LevelFilter::Debug, String::from("./app.log", 1024 * 1024, true, true)?;